pub enum ProjectionEngineVersion {
V1,
V2,
}Expand description
Selects which projection engine the server should use when creating a
continuous projection. V1 is the default and is supported by every server
version. V2 requires a server that supports the next-generation engine.
Variants